.. include:: ../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Contents:

   openweatherwrap/api
   openweatherwrap/asyncapi
   openweatherwrap/core
   openweatherwrap/errors